@@ -89,7 +89,8 @@ vardchanges <- function(Y, H, PSU, w_final,
                          ncols = 1, Yncol = 0, Ynrow = Ynrow,
                          ischaracter = TRUE, namesID1 = names(ID_level1))
 
-        if(!is.null(X)) {
+        if(!is.null(X) | !is.null(ind_gr) | !is.null(g) | !is.null(q) | !is.null(countryX) | 
+             !is.null(periodX) | !is.null(X_ID_level1) | !is.null(datasetX)) {
                 X <- check_var(vars = X, varn = "X", dataset = datasetX,
                                check.names = TRUE, isnumeric = TRUE,
                                dif_name = c(names(period), names(country), names(H),
